#
# spec file for package zk
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zk
Version:        0.14.1
Release:        2.1
Summary:        Plain text note-taking assistant for markdown
License:        BSD-2-Clause
Group:          System/Shells
URL:            https://github.com/zk-org/zk
Source0:        https://github.com/zk-org/zk/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
# PATCH-FIX-UPSTREAM fix_test.patch -- based on commit e3c5784fb84a792491724fe4cc1f26e2c9d01b60
Patch0:         fix_test.patch
BuildRequires:  c_compiler
BuildRequires:  zstd
BuildRequires:  golang(API)
BuildRequires:  pkgconfig(icu-io)
BuildRequires:  pkgconfig(sqlite3)
Requires:       fzf

%description
Zk is a plain text note-taking assistant for markdown.
It is a command-line tool helping you to maintain a plain text Zettelkasten or personal wiki.

%prep
%setup -qa1
%autopatch -p1

%build
%ifarch ppc64
BUILDMOD=""
%else
BUILDMOD="-buildmode=pie"
%endif
export RPM_OPT_FLAGS="%{optflags}"
go build -v -x -mod=vendor $BUILDMOD -a -ldflags "-s -X main.Version=%{version} -X main.Build=578894f" --tags "icu json1 fts5 secure_delete"

%install
install -Dm755 zk %{buildroot}%{_bindir}/zk

%check
make test

%files
%{_bindir}/%{name}
%license LICENSE
%doc CHANGELOG.md README.md docs/*.md

%changelog
* Sun Nov 24 2024 Andrea Manzini <andrea.manzini@suse.com>
- added fix_test.patch to fix build fail due to test TestFormatDateHelperElapsedYear
* Mon May 27 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 0.14.1
  * Fixed parsing large notes @khimaros in #339
  * fix day range parsing (#382) by @tjex in #384
  * accept tripple dash file URIs as valid links by @tjex in #391
  * fix(lsp): fix trigger completion of zk LSP by @Rahlir in #397
  * fix(lsp): ignore diagnostic check within code blocks by @Rahlir in #399
  * allow notebook as hidden dir by @tjex in #402
  * documentation fixes
- project has moved to its own github org
- unit tests run on build
* Tue Mar 19 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Replace vendor.tar.zstd with vendor.tar.zst
* Mon Jun 12 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Set correct version in main.go.
* Sat Jun 10 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 0.14.0:
  * Added
    + New tool.shell configuration key to set a custom shell (contributed by @lsvmello).
    + New notebook.dir configuration key to set the default notebook (contributed by @lsvmello).
  * Changed
    + The note.ignore configuration property was renamed to note.exclude, to be more consistent with the CLI flags.
  * Fixed
    + Fixed LSP positions using UTF-16 offsets (contributed by @wrvsrx).
* Mon Feb 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.13.0:
  * zk.new now returns the created note's content in its output (content), and has two new options:
  * dryRun will prevent zk.new from creating the note on the file system.
  * insertContentAtLocation can be used to insert the created note's content into an arbitrary location.
  * A new zk.link command to insert a link to a given note
* Thu Jan  5 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix specfile.
  * Remove usage of golang-packaging macros. Buggy
- Reset to latest shipped c_compiler.
* Sat Dec 31 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Set gcc less than version 12.
- Requires fzf.
* Sat Dec 31 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- add -tags "fts5" for build and install.
* Fri Dec 23 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Add more docs.
- Recommend fzf since it uses fzf on some commands.
* Sun Dec  4 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for zk 0.12.0
